summaryrefslogtreecommitdiff
path: root/nuttx/configs/fire-stm32v2/src/up_usbmsc.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/fire-stm32v2/src/up_usbmsc.c')
-rw-r--r--nuttx/configs/fire-stm32v2/src/up_usbmsc.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/nuttx/configs/fire-stm32v2/src/up_usbmsc.c b/nuttx/configs/fire-stm32v2/src/up_usbmsc.c
index 3a1ebe0e0..41f966e9d 100644
--- a/nuttx/configs/fire-stm32v2/src/up_usbmsc.c
+++ b/nuttx/configs/fire-stm32v2/src/up_usbmsc.c
@@ -52,8 +52,8 @@
****************************************************************************/
/* Configuration ************************************************************/
-#ifndef CONFIG_EXAMPLES_USBMSC_DEVMINOR1
-# define CONFIG_EXAMPLES_USBMSC_DEVMINOR1 0
+#ifndef CONFIG_SYSTEM_USBMSC_DEVMINOR1
+# define CONFIG_SYSTEM_USBMSC_DEVMINOR1 0
#endif
/* Debug ********************************************************************/
@@ -90,13 +90,13 @@
int usbmsc_archinitialize(void)
{
/* If examples/usbmsc is built as an NSH command, then SD slot should
* already have been initized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.
*/
#ifndef CONFIG_NSH_BUILTIN_APPS
- return stm32_sdinitialize(CONFIG_EXAMPLES_USBMSC_DEVMINOR1);
+ return stm32_sdinitialize(CONFIG_SYSTEM_USBMSC_DEVMINOR1);
#else
return OK;
#endif
@@ -90,13 +90,13 @@
int usbmsc_archinitialize(void)
{
- /* If examples/usbmsc is built as an NSH command, then SD slot should
+ /* If system/usbmsc is built as an NSH command, then SD slot should
* already have been initized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.